==> moengagesdk-3.4.01-sources.jar: com/moengage/core/ConfigurationCache.java <==
package com.moengage.core;

import android.support.annotation.Nullable;
import com.moe.pushlibrary.utils.MoEHelperConstants;
import com.moengage.core.model.RemoteConfiguration;
import java.util.HashMap;
import java.util.List;

/**
 * @author Umang Chamaria
 */
public class ConfigurationCache {

  private HashMap<String, Object> configMap;

  private static ConfigurationCache instance;

  private ConfigurationCache() {
    configMap = new HashMap<>();
  }

  public static ConfigurationCache getInstance() {
    if (instance == null) {
      synchronized (ConfigurationCache.class) {
        if (instance == null) instance = new ConfigurationCache();
      }
    }
    return instance;
  }

  private static final String PUSH_SERVICE = "push_service";

  public void setPushService(String pushService) {
    configMap.put(PUSH_SERVICE, pushService);
  }

  public String getPushService() {
    String pushService = MoEConstants.PUSH_SERVICE_FCM;
    if (configMap.containsKey(PUSH_SERVICE)) {
      pushService = (String) configMap.get(PUSH_SERVICE);
    }
    return pushService;
  }

  private static final String BAIDU_PUSH_STATE = "baidu_push_state";

  void setBaiduPushState(boolean baiduPushState) {
    configMap.put(BAIDU_PUSH_STATE, baiduPushState);
  }

  public boolean getBaiduPushState() {
    return configMap.containsKey(BAIDU_PUSH_STATE)
        && configMap.get(BAIDU_PUSH_STATE) == Boolean.TRUE;
  }

  // push navigation action back-stack opt out
  private static final String BACK_STACK_OPT_OUT = "is_back_stack_opted_out";

  public void setBackStackOptOut(boolean backStackOptOut) {
    configMap.put(BACK_STACK_OPT_OUT, backStackOptOut);
  }

  public boolean isBackStackOptedOut() {
    return configMap.containsKey(BACK_STACK_OPT_OUT)
        && configMap.get(BACK_STACK_OPT_OUT) == Boolean.TRUE;
  }

  private static final String EXTRAS_OPT_OUT = "is_extras_opted_out";

  public void setExtrasOptOut(boolean extrasOptOut) {
    configMap.put(EXTRAS_OPT_OUT, extrasOptOut);
  }

  public boolean isExtrasOptedOut() {
    return configMap.containsKey(EXTRAS_OPT_OUT) && configMap.get(EXTRAS_OPT_OUT) == Boolean.TRUE;
  }

  private static final String OPT_OUT_DEFAULT_INAPP = "is_default_inapp_opted_out";

  public void setDefaultInAppOptOut(boolean defaultInAppOptOut) {
    configMap.put(OPT_OUT_DEFAULT_INAPP, defaultInAppOptOut);
  }

  public boolean isDefaultInAppOptedOut() {
    return configMap.containsKey(OPT_OUT_DEFAULT_INAPP)
        && configMap.get(OPT_OUT_DEFAULT_INAPP) == Boolean.TRUE;
  }

  private static final String MOE_APP_ID = "moe_app_id";

  void setMoEAppId(String appId) {
    configMap.put(MOE_APP_ID, appId);
  }

  String getMoEAppId() {
    return (String) configMap.get(MOE_APP_ID);
  }

  private static final String MOE_DATA_REGION = "moe_data_region";

  public void setMoEDataRegion(int region) {
    configMap.put(MOE_DATA_REGION, region);
  }

  public int getMoEDataRegion() {
    return configMap.containsKey(MOE_DATA_REGION) ? (Integer) configMap.get(MOE_DATA_REGION) :
        MoEHelperConstants.MOE_REGION_DEFAULT;
  }

  private RemoteConfiguration remoteConfiguration;

  public void setRemoteConfiguration(RemoteConfiguration configuration){
    remoteConfiguration = configuration;
  }

  public RemoteConfiguration getRemoteConfiguration(){
    return remoteConfiguration;
  }

  private List<String> activityOptOutList;

  void setActivityOptOutList(List<String> activityOptOutList){
    this.activityOptOutList = activityOptOutList;
  }

  @Nullable List<String> getActivityOptOutList(){
    return activityOptOutList;
  }

}

==> moengagesdk-3.6.01-sources.jar: com/moengage/core/ConfigurationCache.java <==
package com.moengage.core;

import android.support.annotation.Nullable;
import com.moe.pushlibrary.utils.MoEHelperConstants;
import com.moengage.core.model.RemoteConfiguration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author Umang Chamaria
 */
public class ConfigurationCache {

  private HashMap<String, Object> configMap;

  private static ConfigurationCache instance;

  private ConfigurationCache() {
    configMap = new HashMap<>();
   sentScreenNames = new HashSet<>();
  }

  public static ConfigurationCache getInstance() {
    if (instance == null) {
      synchronized (ConfigurationCache.class) {
        if (instance == null) instance = new ConfigurationCache();
      }
    }
    return instance;
  }

  private static final String PUSH_SERVICE = "push_service";

  public void setPushService(String pushService) {
    configMap.put(PUSH_SERVICE, pushService);
  }

  public String getPushService() {
    String pushService = MoEConstants.PUSH_SERVICE_FCM;
    if (configMap.containsKey(PUSH_SERVICE)) {
      pushService = (String) configMap.get(PUSH_SERVICE);
    }
    return pushService;
  }

  private static final String BAIDU_PUSH_STATE = "baidu_push_state";

  void setBaiduPushState(boolean baiduPushState) {
    configMap.put(BAIDU_PUSH_STATE, baiduPushState);
  }

  public boolean getBaiduPushState() {
    return configMap.containsKey(BAIDU_PUSH_STATE)
        && configMap.get(BAIDU_PUSH_STATE) == Boolean.TRUE;
  }

  // push navigation action back-stack opt out
  private static final String BACK_STACK_OPT_OUT = "is_back_stack_opted_out";

  public void setBackStackOptOut(boolean backStackOptOut) {
    configMap.put(BACK_STACK_OPT_OUT, backStackOptOut);
  }

  public boolean isBackStackOptedOut() {
    return configMap.containsKey(BACK_STACK_OPT_OUT)
        && configMap.get(BACK_STACK_OPT_OUT) == Boolean.TRUE;
  }

  private static final String EXTRAS_OPT_OUT = "is_extras_opted_out";

  public void setExtrasOptOut(boolean extrasOptOut) {
    configMap.put(EXTRAS_OPT_OUT, extrasOptOut);
  }

  public boolean isExtrasOptedOut() {
    return configMap.containsKey(EXTRAS_OPT_OUT) && configMap.get(EXTRAS_OPT_OUT) == Boolean.TRUE;
  }

  private static final String OPT_OUT_DEFAULT_INAPP = "is_default_inapp_opted_out";

  public void setDefaultInAppOptOut(boolean defaultInAppOptOut) {
    configMap.put(OPT_OUT_DEFAULT_INAPP, defaultInAppOptOut);
  }

  public boolean isDefaultInAppOptedOut() {
    return configMap.containsKey(OPT_OUT_DEFAULT_INAPP)
        && configMap.get(OPT_OUT_DEFAULT_INAPP) == Boolean.TRUE;
  }

  private static final String MOE_APP_ID = "moe_app_id";

  void setMoEAppId(String appId) {
    configMap.put(MOE_APP_ID, appId);
  }

  String getMoEAppId() {
    return (String) configMap.get(MOE_APP_ID);
  }

  private static final String MOE_DATA_REGION = "moe_data_region";

  public void setMoEDataRegion(int region) {
    configMap.put(MOE_DATA_REGION, region);
  }

  public int getMoEDataRegion() {
    return configMap.containsKey(MOE_DATA_REGION) ? (Integer) configMap.get(MOE_DATA_REGION) :
        MoEHelperConstants.MOE_REGION_DEFAULT;
  }

  private RemoteConfiguration remoteConfiguration;

  public void setRemoteConfiguration(RemoteConfiguration configuration){
    remoteConfiguration = configuration;
  }

  public RemoteConfiguration getRemoteConfiguration(){
    return remoteConfiguration;
  }

  private List<String> activityOptOutList;

  void setActivityOptOutList(List<String> activityOptOutList){
    this.activityOptOutList = activityOptOutList;
  }

  @Nullable List<String> getActivityOptOutList(){
    return activityOptOutList;
  }

  private Set<String> sentScreenNames;

  void initialiseSentScreens(Set<String> sentScreenNames){
    this.sentScreenNames.addAll(sentScreenNames);
  }

  void addScreenToSentList(String screenName){
    sentScreenNames.add(screenName);
  }

  Set<String> getSentScreenNames(){
    return sentScreenNames;
  }

}
